@@ -1,11 +1,11 @@
 /*
  * SPDX-License-Identifier: GPL-3.0-only
- * MuseScore-CLA-applies
+ * MuseScore-Studio-CLA-applies
  *
- * MuseScore
+ * MuseScore Studio
  * Music Composition & Notation
  *
- * Copyright (C) 2021 MuseScore BVBA and others
+ * Copyright (C) 2021 MuseScore Limited
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 3 as
@@ -54,13 +54,17 @@ using namespace mu::engraving;
 
 namespace mu::engraving {
 static const ElementStyle glissandoElementStyle {
-    { Sid::glissandoFontFace,  Pid::FONT_FACE },
-    { Sid::glissandoFontSize,  Pid::FONT_SIZE },
-    { Sid::glissandoFontStyle, Pid::FONT_STYLE },
-    { Sid::glissandoLineWidth, Pid::LINE_WIDTH },
-    { Sid::glissandoText,      Pid::GLISS_TEXT },
-    { Sid::glissandoStyle,     Pid::GLISS_STYLE },
-    { Sid::glissandoStyleHarp, Pid::GLISS_STYLE }
+    { Sid::glissandoFontFace,    Pid::FONT_FACE },
+    { Sid::glissandoFontSize,    Pid::FONT_SIZE },
+    { Sid::glissandoFontStyle,   Pid::FONT_STYLE },
+    { Sid::glissandoLineWidth,   Pid::LINE_WIDTH },
+    { Sid::glissandoShowText,    Pid::GLISS_SHOW_TEXT },
+    { Sid::glissandoText,        Pid::GLISS_TEXT },
+    { Sid::glissandoStyle,       Pid::GLISS_STYLE },
+    { Sid::glissandoLineStyle,   Pid::LINE_STYLE },
+    { Sid::glissandoDashLineLen, Pid::DASH_LINE_LEN },
+    { Sid::glissandoDashGapLen,  Pid::DASH_GAP_LEN },
+    { Sid::glissandoType,        Pid::GLISS_TYPE }
 };
 
 //=========================================================
@@ -86,7 +90,6 @@ EngravingItem* GlissandoSegment::propertyDelegate(Pid pid)
     case Pid::GLISS_SHIFT:
     case Pid::GLISS_EASEIN:
     case Pid::GLISS_EASEOUT:
-    case Pid::PLAY:
     case Pid::FONT_FACE:
     case Pid::FONT_SIZE:
     case Pid::FONT_STYLE:
@@ -104,19 +107,19 @@ EngravingItem* GlissandoSegment::propertyDelegate(Pid pid)
 Glissando::Glissando(EngravingItem* parent)
     : SLine(ElementType::GLISSANDO, parent, ElementFlag::MOVABLE)
 {
-    setAnchor(Spanner::Anchor::NOTE);
-    setDiagonal(true);
-
     initElementStyle(&glissandoElementStyle);
 
-    resetProperty(Pid::GLISS_SHOW_TEXT);
-    resetProperty(Pid::PLAY);
-    resetProperty(Pid::GLISS_STYLE);
-    resetProperty(Pid::GLISS_SHIFT);
-    resetProperty(Pid::GLISS_TYPE);
-    resetProperty(Pid::GLISS_TEXT);
-    resetProperty(Pid::GLISS_EASEIN);
-    resetProperty(Pid::GLISS_EASEOUT);
+    static const std::array<Pid, 5> propertiesToInitialise {
+        Pid::GLISS_SHIFT,
+        Pid::GLISS_EASEIN,
+        Pid::GLISS_EASEOUT,
+        Pid::DIAGONAL,
+        Pid::ANCHOR
+    };
+
+    for (const Pid& pid : propertiesToInitialise) {
+        resetProperty(pid);
+    }
 }
 
 Glissando::Glissando(const Glissando& g)
@@ -131,16 +134,10 @@ Glissando::Glissando(const Glissando& g)
     _easeIn         = g._easeIn;
     _easeOut        = g._easeOut;
     _showText       = g._showText;
-    _playGlissando  = g._playGlissando;
     _fontStyle      = g._fontStyle;
     m_isHarpGliss   = g.m_isHarpGliss;
 }
 
-const TranslatableString& Glissando::glissandoTypeName() const
-{
-    return TConv::userName(glissandoType());
-}
-
 //---------------------------------------------------------
 //   createLineSegment
 //---------------------------------------------------------
@@ -162,36 +159,13 @@ Sid Glissando::getPropertyStyle(Pid id) const
     return SLine::getPropertyStyle(id);
 }
 
-void Glissando::addLineAttachPoints()
-{
-    GlissandoSegment* frontSeg = toGlissandoSegment(frontSegment());
-    GlissandoSegment* backSeg = toGlissandoSegment(backSegment());
-    Note* startNote = nullptr;
-    Note* endNote = nullptr;
-    if (startElement() && startElement()->isNote()) {
-        startNote = toNote(startElement());
-    }
-    if (endElement() && endElement()->isNote()) {
-        endNote = toNote(endElement());
-    }
-    if (!frontSeg || !backSeg || !startNote || !endNote) {
-        return;
-    }
-    double startX = frontSeg->ldata()->pos().x();
-    double endX = backSeg->pos2().x() + backSeg->ldata()->pos().x(); // because pos2 is relative to ipos
-    // Here we don't pass y() because its value is unreliable during the first stages of layout.
-    // The y() is irrelevant anyway for horizontal spacing.
-    startNote->addLineAttachPoint(PointF(startX, 0.0), this);
-    endNote->addLineAttachPoint(PointF(endX, 0.0), this);
-}
-
 bool Glissando::pitchSteps(const Spanner* spanner, std::vector<int>& pitchOffsets)
 {
     if (!spanner->endElement()->isNote()) {
         return false;
     }
     const Glissando* glissando = toGlissando(spanner);
-    if (!glissando->playGlissando()) {
+    if (!glissando->playSpanner()) {
         return false;
     }
     GlissandoStyle glissandoStyle = glissando->glissandoStyle();
@@ -261,7 +235,7 @@ bool Glissando::pitchSteps(const Spanner* spanner, std::vector<int>& pitchOffset
         }
         return true;
     }
-    static std::vector<bool> whiteNotes = { true, false, true, false, true, true, false, true, false, true, false, true };
+    static const std::vector<bool> whiteNotes = { true, false, true, false, true, true, false, true, false, true, false, true };
     int Cnote = 60;   // pitch of middle C
     bool notePick = glissandoStyle == GlissandoStyle::WHITE_KEYS;
     for (int pitch = pitchStart; pitch != pitchEnd; pitch += direction) {
@@ -370,81 +344,6 @@ Note* Glissando::guessInitialNote(Chord* chord)
     return 0;
 }
 
-Note* Glissando::guessFinalNote(Chord* chord, Note* startNote)
-{
-    if (chord->isGraceBefore()) {
-        Chord* parentChord = toChord(chord->parent());
-        GraceNotesGroup& gracesBefore = parentChord->graceNotesBefore();
-        auto positionOfThis = std::find(gracesBefore.begin(), gracesBefore.end(), chord);
-        if (positionOfThis != gracesBefore.end()) {
-            auto nextPosition = ++positionOfThis;
-            if (nextPosition != gracesBefore.end()) {
-                return (*nextPosition)->upNote();
-            }
-        }
-        return parentChord->upNote();
-    } else if (chord->isGraceAfter()) {
-        Chord* parentChord = toChord(chord->parent());
-        GraceNotesGroup& gracesAfter = parentChord->graceNotesAfter();
-        auto positionOfThis = std::find(gracesAfter.begin(), gracesAfter.end(), chord);
-        if (positionOfThis != gracesAfter.end()) {
-            auto nextPosition = ++positionOfThis;
-            if (nextPosition != gracesAfter.end()) {
-                return (*nextPosition)->upNote();
-            }
-        }
-        chord = toChord(chord->parent());
-    } else {
-        std::vector<Chord*> graces = chord->graceNotesAfter();
-        if (graces.size() > 0) {
-            return graces.front()->upNote();
-        }
-    }
-
-    if (!chord->explicitParent()->isSegment()) {
-        return 0;
-    }
-
-    Segment* segm = chord->score()->tick2rightSegment(chord->tick() + chord->actualTicks());
-    while (segm && !segm->isChordRestType()) {
-        segm = segm->next1();
-    }
-
-    if (!segm) {
-        return nullptr;
-    }
-
-    track_idx_t chordTrack = chord->track();
-    Part* part = chord->part();
-
-    Chord* target = nullptr;
-    if (segm->element(chordTrack) && segm->element(chordTrack)->isChord()) {
-        target = toChord(segm->element(chordTrack));
-    } else {
-        for (EngravingItem* currChord : segm->elist()) {
-            if (currChord && currChord->isChord() && toChord(currChord)->part() == part) {
-                target = toChord(currChord);
-                break;
-            }
-        }
-    }
-
-    if (target && target->notes().size() > 0) {
-        const std::vector<Chord*>& graces = target->graceNotesBefore();
-        if (graces.size() > 0) {
-            return graces.front()->upNote();
-        }
-        // normal case: try to return the note in the next chord that is in the
-        // same position as the start note relative to the end chord
-        size_t startNoteIdx = mu::indexOf(chord->notes(), startNote);
-        size_t endNoteIdx = std::min(startNoteIdx, target->notes().size() - 1);
-        return target->notes().at(endNoteIdx);
-    }
-
-    LOGD("no second note for glissando found");
-    return nullptr;
-}
-
 //---------------------------------------------------------
 //   getProperty
 //---------------------------------------------------------
@@ -466,8 +365,6 @@ PropertyValue Glissando::getProperty(Pid propertyId) const
         return easeIn();
     case Pid::GLISS_EASEOUT:
         return easeOut();
-    case Pid::PLAY:
-        return bool(playGlissando());
     case Pid::FONT_FACE:
         return _fontFace;
     case Pid::FONT_SIZE:
@@ -515,9 +412,6 @@ bool Glissando::setProperty(Pid propertyId, const PropertyValue& v)
     case Pid::GLISS_EASEOUT:
         setEaseOut(v.toInt());
         break;
-    case Pid::PLAY:
-        setPlayGlissando(v.toBool());
-        break;
     case Pid::FONT_FACE:
         setFontFace(v.value<String>());
         break;
@@ -545,7 +439,7 @@ PropertyValue Glissando::propertyDefault(Pid propertyId) const
 {
     switch (propertyId) {
     case Pid::GLISS_TYPE:
-        return int(GlissandoType::STRAIGHT);
+        return style().styleV(Sid::glissandoType);
     case Pid::GLISS_SHOW_TEXT:
         return true;
     case Pid::GLISS_STYLE:
@@ -555,11 +449,20 @@ PropertyValue Glissando::propertyDefault(Pid propertyId) const
     case Pid::GLISS_EASEIN:
     case Pid::GLISS_EASEOUT:
         return 0;
-    case Pid::PLAY:
+    case Pid::GLISS_TEXT:
+        return style().styleV(Sid::glissandoText);
+    case Pid::DIAGONAL:
         return true;
+    case Pid::ANCHOR:
+        return int(Spanner::Anchor::NOTE);
     default:
         break;
     }
     return SLine::propertyDefault(propertyId);
 }
+
+TranslatableString Glissando::subtypeUserName() const
+{
+    return TConv::userName(glissandoType());
+}
 }
